@@ -32,11 +32,10 @@ class Terms(ApiBase):
         ApiBase.__init__(self, ns_client=ns_client, type_name='Term')
 
     def post(self, data) -> OrderedDict:
-        assert data['externalId'], 'missing external id'
-        term = self.ns_client.Term(externalId=data['externalId'], name=data['name'])
+        term = self.ns_client.Term(daysUntilNetDue=data['daysUntilNetDue'], name=data['name'])
 
         self.build_simple_fields(self.SIMPLE_FIELDS, data, term)
 
         logger.debug('able to create term = %s', term)
-        res = self.ns_client.upsert(term)
+        res = self.ns_client.request('add', record=term)
         return self._serialize(res)
